@@ -1,10 +1,9 @@
 /* ***** BEGIN LICENSE BLOCK *****
-* Version: MPL 1.1
+* Version: MPL 2.0
 *
-* The contents of this file are subject to the Mozilla Public License Version
-* 1.1 (the "License"); you may not use this file except in compliance with
-* the License. You may obtain a copy of the License at
-* http://www.mozilla.org/MPL/
+* This Source Code Form is subject to the terms of the Mozilla Public
+* License, v. 2.0. If a copy of the MPL was not distributed with this
+* file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
@@ -49,7 +48,7 @@
 #include <numeric>
 #include <memory>
 #include <cstring>
-
+#include <cstdio>
 
 #include "stringkernel.h"
 
